==> jc-1.4.0.tar.gz: gnu/java/security/provider/DefaultPolicy.h <==
// public class gnu.java.security.provider.DefaultPolicy

// class file dependencies
// @dep_class 65ef7189d73fd1d6 gnu_java_security_provider_DefaultPolicy
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 22e7d19b890f754a java_security_Policy

// header file dependencies
// @dep_header java_security_Policy

#include "java/security/Policy.h"

#ifndef _JC_gnu_java_security_provider_DefaultPolicy_H_
#define _JC_gnu_java_security_provider_DefaultPolicy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_CodeSource$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$sub_refs	_jc_gnu_java_security_provider_DefaultPolicy$sub_refs;
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$sub_nonrefs	_jc_gnu_java_security_provider_DefaultPolicy$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$refs	_jc_gnu_java_security_provider_DefaultPolicy$refs;
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$nonrefs	_jc_gnu_java_security_provider_DefaultPolicy$nonrefs;
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$object	_jc_gnu_java_security_provider_DefaultPolicy$object;

typedef struct _jc_gnu_java_security_provider_DefaultPolicy$fields_struct	_jc_gnu_java_security_provider_DefaultPolicy$fields_struct;
typedef const struct _jc_gnu_java_security_provider_DefaultPolicy$vmethods	_jc_gnu_java_security_provider_DefaultPolicy$vmethods;
typedef const struct _jc_gnu_java_security_provider_DefaultPolicy$vtable	_jc_gnu_java_security_provider_DefaultPolicy$vtable;
typedef const struct _jc_gnu_java_security_provider_DefaultPolicy$vtype	_jc_gnu_java_security_provider_DefaultPolicy$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_DefaultPolicy$fields_struct {
	struct _jc_java_security_Permission$object	*allPermission;
};
extern _jc_gnu_java_security_provider_DefaultPolicy$fields_struct _jc_gnu_java_security_provider_DefaultPolicy$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_DefaultPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *);

// Virtual methods
extern struct _jc_java_security_PermissionCollection$object *_jc_gnu_java_security_provider_DefaultPolicy$method$getPermissions$448009107719f384(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *, struct _jc_java_security_CodeSource$object *);
extern void _jc_gnu_java_security_provider_DefaultPolicy$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DefaultPolicy$method_info$getPermissions$448009107719f384;
extern _jc_method _jc_gnu_java_security_provider_DefaultPolicy$method_info$refresh$23f3d9d8f6b36945;

// Static methods
extern void _jc_gnu_java_security_provider_DefaultPolicy$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_security_provider_DefaultPolicy$vmethods {
	struct _jc_java_security_PermissionCollection$object	*(*getPermissions$448009107719f384)(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *, struct _jc_java_security_CodeSource$object *);
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *);
};

// Vtable
struct _jc_gnu_java_security_provider_DefaultPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Policy$vmethods	java_security_Policy;
	_jc_gnu_java_security_provider_DefaultPolicy$vmethods	gnu_java_security_provider_DefaultPolicy;
};

// Vtype
struct _jc_gnu_java_security_provider_DefaultPolicy$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DefaultPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DefaultPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DefaultPolicy$refs {
    _jc_gnu_java_security_provider_DefaultPolicy$sub_refs	gnu_java_security_provider_DefaultPolicy;
    _jc_java_security_Policy$sub_refs	java_security_Policy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DefaultPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DefaultPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Policy$sub_nonrefs	java_security_Policy;
    _jc_gnu_java_security_provider_DefaultPolicy$sub_nonrefs	gnu_java_security_provider_DefaultPolicy;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DefaultPolicy$object {
	_jc_gnu_java_security_provider_DefaultPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DefaultPolicy$vtype	*vtype;
	_jc_gnu_java_security_provider_DefaultPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DefaultPolicy$vtype _jc_gnu_java_security_provider_DefaultPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DefaultPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DefaultPolicy$class_object;

#endif	/* _JC_gnu_java_security_provider_DefaultPolicy_H_ */

==> jc-1.4.6.tar.gz: gnu/java/security/provider/DefaultPolicy.h <==
// public class gnu.java.security.provider.DefaultPolicy

// class file dependencies
// @dep_class c36e76f279a4bf92 gnu_java_security_provider_DefaultPolicy
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 22e7d19b890f754a java_security_Policy

// header file dependencies
// @dep_header java_security_Policy

#include "java/security/Policy.h"

#ifndef _JC_gnu_java_security_provider_DefaultPolicy_H_
#define _JC_gnu_java_security_provider_DefaultPolicy_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_security_CodeSource$object;
struct _jc_java_security_Permission$object;
struct _jc_java_security_PermissionCollection$object;

// Typedefs
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$sub_refs	_jc_gnu_java_security_provider_DefaultPolicy$sub_refs;
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$sub_nonrefs	_jc_gnu_java_security_provider_DefaultPolicy$sub_nonrefs;
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$refs	_jc_gnu_java_security_provider_DefaultPolicy$refs;
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$nonrefs	_jc_gnu_java_security_provider_DefaultPolicy$nonrefs;
typedef struct _jc_gnu_java_security_provider_DefaultPolicy$object	_jc_gnu_java_security_provider_DefaultPolicy$object;

typedef struct _jc_gnu_java_security_provider_DefaultPolicy$fields_struct	_jc_gnu_java_security_provider_DefaultPolicy$fields_struct;
typedef const struct _jc_gnu_java_security_provider_DefaultPolicy$vmethods	_jc_gnu_java_security_provider_DefaultPolicy$vmethods;
typedef const struct _jc_gnu_java_security_provider_DefaultPolicy$vtable	_jc_gnu_java_security_provider_DefaultPolicy$vtable;
typedef const struct _jc_gnu_java_security_provider_DefaultPolicy$vtype	_jc_gnu_java_security_provider_DefaultPolicy$vtype;

// Class fields structure
struct _jc_gnu_java_security_provider_DefaultPolicy$fields_struct {
	struct _jc_java_security_Permission$object	*allPermission;
};
extern _jc_gnu_java_security_provider_DefaultPolicy$fields_struct _jc_gnu_java_security_provider_DefaultPolicy$class_fields;

// Constructors
extern void _jc_gnu_java_security_provider_DefaultPolicy$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_security_PermissionCollection$object *_jc_gnu_java_security_provider_DefaultPolicy$method$getPermissions$448009107719f384(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_security_provider_DefaultPolicy$method$refresh$23f3d9d8f6b36945(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_security_provider_DefaultPolicy$method_info$getPermissions$448009107719f384;
extern _jc_method _jc_gnu_java_security_provider_DefaultPolicy$method_info$refresh$23f3d9d8f6b36945;

// Static methods
extern void _jc_gnu_java_security_provider_DefaultPolicy$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_security_provider_DefaultPolicy$vmethods {
	struct _jc_java_security_PermissionCollection$object	*(*getPermissions$448009107719f384)(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *, struct _jc_java_security_CodeSource$object *) _JC_JCNI_ATTR;
	void	(*refresh$23f3d9d8f6b36945)(_jc_env *, struct _jc_gnu_java_security_provider_DefaultPolicy$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_security_provider_DefaultPolicy$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_security_Policy$vmethods	java_security_Policy;
	_jc_gnu_java_security_provider_DefaultPolicy$vmethods	gnu_java_security_provider_DefaultPolicy;
};

// Vtype
struct _jc_gnu_java_security_provider_DefaultPolicy$vtype {
	_jc_type			type;
	_jc_gnu_java_security_provider_DefaultPolicy$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DefaultPolicy$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_security_provider_DefaultPolicy$refs {
    _jc_gnu_java_security_provider_DefaultPolicy$sub_refs	gnu_java_security_provider_DefaultPolicy;
    _jc_java_security_Policy$sub_refs	java_security_Policy;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_security_provider_DefaultPolicy$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_security_provider_DefaultPolicy$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_security_Policy$sub_nonrefs	java_security_Policy;
    _jc_gnu_java_security_provider_DefaultPolicy$sub_nonrefs	gnu_java_security_provider_DefaultPolicy;
};

// Object instance structure
struct _jc_gnu_java_security_provider_DefaultPolicy$object {
	_jc_gnu_java_security_provider_DefaultPolicy$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_security_provider_DefaultPolicy$vtype	*vtype;
	_jc_gnu_java_security_provider_DefaultPolicy$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_security_provider_DefaultPolicy$vtype _jc_gnu_java_security_provider_DefaultPolicy$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_security_provider_DefaultPolicy, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_security_provider_DefaultPolicy$class_object;

#endif	/* _JC_gnu_java_security_provider_DefaultPolicy_H_ */
